package com.yiqi.order.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.order.domain.OrderClothFlaw;

/**
 * 洗衣订单衣服瑕疵Service接口
 *
 * @author ruoyi
 * @date 2023-10-06
 */
public interface IOrderClothFlawService extends IService<OrderClothFlaw> {
    /**
     * 查询洗衣订单衣服瑕疵
     *
     * @param id 洗衣订单衣服瑕疵主键
     * @return 洗衣订单衣服瑕疵
     */
    public OrderClothFlaw selectOrderClothFlawById(Long id);

    /**
     * 查询洗衣订单衣服瑕疵列表
     *
     * @param orderClothFlaw 洗衣订单衣服瑕疵
     * @return 洗衣订单衣服瑕疵集合
     */
    public List<OrderClothFlaw> selectOrderClothFlawList(OrderClothFlaw orderClothFlaw);

    /**
     * 新增洗衣订单衣服瑕疵
     *
     * @param orderClothFlaw 洗衣订单衣服瑕疵
     * @return 结果
     */
    public int insertOrderClothFlaw(OrderClothFlaw orderClothFlaw);

    /**
     * 修改洗衣订单衣服瑕疵
     *
     * @param orderClothFlaw 洗衣订单衣服瑕疵
     * @return 结果
     */
    public int updateOrderClothFlaw(OrderClothFlaw orderClothFlaw);

    /**
     * 批量删除洗衣订单衣服瑕疵
     *
     * @param ids 需要删除的洗衣订单衣服瑕疵主键集合
     * @return 结果
     */
    public int deleteOrderClothFlawByIds(Long[] ids);

    /**
     * 删除洗衣订单衣服瑕疵信息
     *
     * @param id 洗衣订单衣服瑕疵主键
     * @return 结果
     */
    public int deleteOrderClothFlawById(Long id);



}
